@@ -8,7 +8,8 @@ feature_schema = Schema({
     Optional('encoder_attrs'): dict,
     Optional('depends_on_column'): str,
     Optional('dropout'): float,
-    Optional('weights'): dict
+    Optional('weights'): dict,
+    Optional('secondary_type'): And(str, Use(str.lower), lambda s: s in COLUMN_DATA_TYPES.get_attributes().values())
 })
 
 mixer_graph_schema = Schema({
