@@ -81,19 +81,3 @@ class TsFreshTsEncoder(BaseEncoder):
 
     def decode(self, encoded_values_tensor):
         raise Exception('This encoder is not bi-directional')
-
-
-# only run the test if this file is called from debugger, it takes <1 min
-if __name__ == "__main__":
-    import math
-
-    data = [" ".join(str(math.sin(i / 100)) for i in range(1, 10)) for j in range(20)]
-
-    enc = TsFreshTsEncoder()
-    enc.prepare_encoder(data)
-    ret = enc.encode(data)
-
-    print(ret)
-    print(f'Got above vecotr of lenght: {len(ret)} and feature lenght: {len(ret[0])} for that of length {len(data)} and member length {len(data[0])}')
-    assert(len(ret) == len(data))
-    assert(len(ret) < 60)
